==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/enums/PartnerConfigurationProvisioningState.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Provisioning state of the partner configuration.
 */
public enum class PartnerConfigurationProvisioningState(
    public val javaValue:
    com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState> {
    Creating(com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState.Creating),
    Updating(com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState.Updating),
    Deleting(com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState.Deleting),
    Succeeded(com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState.Succeeded),
    Canceled(com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState.Canceled),
    Failed(com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState.Failed),
    ;

    override fun toJava():
        com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState = javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState):
            PartnerConfigurationProvisioningState =
            PartnerConfigurationProvisioningState.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/enums/PartnerConfigurationProvisioningState.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Provisioning state of the partner configuration.
 */
public enum class PartnerConfigurationProvisioningState(
    public val javaValue: com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState> {
    Creating(com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState.Creating),
    Updating(com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState.Updating),
    Deleting(com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState.Deleting),
    Succeeded(com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState.Succeeded),
    Canceled(com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState.Canceled),
    Failed(com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState.Failed),
    ;

    override fun toJava(): com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.eventgrid.enums.PartnerConfigurationProvisioningState): PartnerConfigurationProvisioningState =
            PartnerConfigurationProvisioningState.values().first { it.javaValue == javaType }
    }
}
